import * as react_jsx_runtime from 'react/jsx-runtime';
import { SpacingTypes } from '@versini/ui-spacing-types';

type FlexgridProps = {
	/**
	 * Children of the Flexgrid (FlexgridItem(s) or any other nodes).
	 */
	children: React.ReactNode;

	/**
	 * Equivalent to "justify-content" in flexbox, this prop defines
	 * the alignment along the main axis (horizontal).
	 */
	alignHorizontal?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "space-between"
		| "space-around"
		| "space-evenly";

	/**
	 * Equivalent to "align-items" in flexbox, this prop defines
	 * the alignment along the cross axis (vertical).
	 */
	alignVertical?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "stretch"
		| "baseline";

	/**
	 * The class name of the Flexgrid.
	 * It follows the [CSS class name property](https://developer.mozilla.org/en-US/docs/Web/CSS/class).
	 */
	className?: string;

	/**
	 * Width of the gutters between the columns.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	columnGap?: number;

	/**
	 * Equivalent to "flex-direction" in flexbox, this prop
	 * establishes the main-axis, thus defining the direction
	 * flex items are placed in the flex container. Flexbox is
	 * (aside from optional wrapping) a single-direction layout
	 * concept. Think of flex items as primarily laying out
	 * either in horizontal rows or vertical columns.
	 */
	direction?: "row" | "row-reverse" | "column" | "column-reverse";

	/**
	 * The height of the Flexgrid.
	 * It follows the [CSS height property](https://developer.mozilla.org/en-US/docs/Web/CSS/height).
	 */
	height?: string;

	/**
	 * Width of the gutters between the rows.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	rowGap?: number;

	/**
	 * The width of the Flexgrid.
	 * It follows the [CSS width property](https://developer.mozilla.org/en-US/docs/Web/CSS/width).
	 */
	width?: string;
} & SpacingTypes.Props;

type FlexgridItemProps = {
	/** Children of the FlexgridItem. */
	children?: React.ReactNode;

	/** Classname to apply to the FlexgridItem. */
	className?: string;

	/** The item will span across the provided number of grid tracks. */
	span?:
		| number
		| "auto"
		| {
				fallback?: number;
				lg?: number;
				md?: number;
				sm?: number;
				xl?: number;
		  };
};

declare const Flexgrid: ({ children, className, columnGap, rowGap, height, width, direction, alignHorizontal, alignVertical, spacing, ...otherProps }: FlexgridProps) => react_jsx_runtime.JSX.Element;

/**
 * FlexgridItem is a child of Flexgrid. It is used to define the width of a
 * column in a Flexgrid. It can be used to span across multiple columns in a
 * Flexgrid by providing a number of columns or "auto" value to the `span` prop.
 */
declare const FlexgridItem: ({ children, className, span, ...otherProps }: FlexgridItemProps) => react_jsx_runtime.JSX.Element;

type ThemeProviderProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * An object specifying custom properties impacting the base theme.
	 * Not all custom properties need to be specified.
	 * @example
	 * ```tsx
	 * // this will change the color of the button to red.
	 * <ThemeProvider customTheme={{ '--av-action-dark': 'red' }}>
	 *  <Button kind="dark">Click me</Button>
	 * </ThemeProvider>
	 * ```
	 */
	customTheme?: Record<string, string>;
	/**
	 * Whether to apply the theme globally or not.
	 * @default false
	 */
	global?: boolean;
} & SpacingTypes.Props;

declare const ThemeProvider: ({ customTheme, children, global, className, spacing, }: ThemeProviderProps) => react_jsx_runtime.JSX.Element;

export { Flexgrid, FlexgridItem, ThemeProvider };
